## Summary Table

| Stanza Id | Title | Links |
| --------- | ----- | ----- |
| S138006 | SiReN: Sign-Aware GNN Recommender | <a href="https://github.com/RecoHut-Stanzas/S138006/blob/main/reports/S138006_Report.ipynb" alt="S138006_Report"> <img src="https://img.shields.io/static/v1?label=report&message=active&color=green" /></a><a href="https://github.com/RecoHut-Stanzas/S138006" alt="S138006"> <img src="https://img.shields.io/static/v1?label=code&message=github&color=blue" /></a> |
| S394070 | Deep Variational Models for Collaborative Filtering-based Recommender Systems | <a href="https://github.com/RecoHut-Stanzas/S394070/blob/main/reports/S394070_Report.ipynb" alt="S394070_Report"> <img src="https://img.shields.io/static/v1?label=report&message=active&color=green" /></a><a href="https://github.com/RecoHut-Stanzas/S394070" alt="S394070"> <img src="https://img.shields.io/static/v1?label=code&message=github&color=blue" /></a> |
| S758139 | DRGR: Deep Reinforcement learning based Group Recommender system | <a href="https://github.com/RecoHut-Stanzas/S758139/blob/main/reports/S758139_Report.ipynb" alt="S758139_Report"> <img src="https://img.shields.io/static/v1?label=report&message=active&color=green" /></a><a href="https://github.com/RecoHut-Stanzas/S758139" alt="S758139"> <img src="https://img.shields.io/static/v1?label=code&message=github&color=blue" /></a> |
| S758139 | RL101: Reinforcement Learning Fundamentals | <a href="https://htmlpreview.github.io/?https://github.com/RecoHut-Stanzas/S990517/blob/main/reports/S990517.html" alt="S990517_Report"> <img src="https://img.shields.io/static/v1?label=report&message=active&color=green" /></a><a href="https://github.com/RecoHut-Stanzas/S990517" alt="S990517"> <img src="https://img.shields.io/static/v1?label=code&message=github&color=blue" /></a> |
| S021355 | Building 15 Matching and Ranking Recommendation Models from scratch in Tensorflow | <a href="https://github.com/RecoHut-Stanzas/S021355/blob/main/reports/S021355.ipynb" alt="S021355_Report"> <img src="https://img.shields.io/static/v1?label=report&message=active&color=green" /></a><a href="https://github.com/RecoHut-Stanzas/S021355" alt="S021355"> <img src="https://img.shields.io/static/v1?label=code&message=github&color=blue" /></a> |
| S486984 | Data Science Basics and Real-world Case Studies | <a href="https://github.com/RecoHut-Stanzas/S486984/blob/main/reports/S486984_report.ipynb" alt="S486984_report"> <img src="https://img.shields.io/static/v1?label=report&message=active&color=green" /></a><a href="https://github.com/RecoHut-Stanzas/S486984" alt="S486984"> <img src="https://img.shields.io/static/v1?label=code&message=github&color=blue" /></a> |
| S693545 | Learning Graph Embeddings with HMLET (End) Model | <a href="https://github.com/RecoHut-Stanzas/S693545/blob/main/reports/S693545_report.ipynb" alt="S693545_report"> <img src="https://img.shields.io/static/v1?label=report&message=active&color=green" /></a><a href="https://github.com/RecoHut-Stanzas/S693545" alt="S693545"> <img src="https://img.shields.io/static/v1?label=code&message=github&color=blue" /></a> |
| S318140 | IEEE Challenge 2021 Session-aware Recommendation with Transformer | <a href="https://htmlpreview.github.io/?https://github.com/RecoHut-Stanzas/S318140/blob/main/reports/S318140_report.html" alt="S318140_report"> <img src="https://img.shields.io/static/v1?label=report&message=active&color=green" /></a><a href="https://github.com/RecoHut-Stanzas/S318140" alt="S318140"> <img src="https://img.shields.io/static/v1?label=code&message=github&color=blue" /></a> |
| S593234 | Basic Retail Recommender | <a href="https://github.com/RecoHut-Stanzas/S593234/blob/main/reports/S593234_report.ipynb" alt="S593234_report"> <img src="https://img.shields.io/static/v1?label=report&message=active&color=green" /></a><a href="https://github.com/RecoHut-Stanzas/S593234" alt="S593234"> <img src="https://img.shields.io/static/v1?label=code&message=github&color=blue" /></a> |
| S691423 | D-Optimal Online Experiment Design for Recommender Selection | <a href="https://github.com/RecoHut-Stanzas/S691423/blob/main/reports/S691423_report.ipynb" alt="S691423_report"> <img src="https://img.shields.io/static/v1?label=report&message=active&color=green" /></a><a href="https://github.com/RecoHut-Stanzas/S691423" alt="S691423"> <img src="https://img.shields.io/static/v1?label=code&message=github&color=blue" /></a> |
| S165806 | Group Playlist Recommender | <a href="https://github.com/RecoHut-Stanzas/S165806/blob/main/reports/S165806_report.ipynb" alt="S165806_report"> <img src="https://img.shields.io/static/v1?label=report&message=active&color=green" /></a><a href="https://github.com/RecoHut-Stanzas/S165806" alt="S165806"> <img src="https://img.shields.io/static/v1?label=code&message=github&color=blue" /></a> |
| S794944 | LR-GCCF: Graph-based Recommender Model | <a href="https://github.com/RecoHut-Stanzas/S794944/blob/main/reports/S794944_report.ipynb" alt="S794944_report"> <img src="https://img.shields.io/static/v1?label=report&message=active&color=green" /></a><a href="https://github.com/RecoHut-Stanzas/S794944" alt="S794944"> <img src="https://img.shields.io/static/v1?label=code&message=github&color=blue" /></a> |
| S516304 | CTR Models in PyTorch | <a href="https://github.com/RecoHut-Stanzas/S516304/blob/main/reports/S516304_report.ipynb" alt="S516304_report"> <img src="https://img.shields.io/static/v1?label=report&message=active&color=green" /></a><a href="https://github.com/RecoHut-Stanzas/S516304" alt="S516304"> <img src="https://img.shields.io/static/v1?label=code&message=github&color=blue" /></a> |
| S181315 | SLIST: Session-aware Linear Item-Item Model for Session-based Recommendation | <a href="https://github.com/RecoHut-Stanzas/S181315/blob/main/reports/S181315_report.ipynb" alt="S181315_report"> <img src="https://img.shields.io/static/v1?label=report&message=active&color=green" /></a><a href="https://github.com/RecoHut-Stanzas/S181315" alt="S181315"> <img src="https://img.shields.io/static/v1?label=code&message=github&color=blue" /></a> |
| S819118 | Predictability limits in session-based next item recommendation | <a href="https://github.com/RecoHut-Stanzas/S819118/blob/main/reports/S819118_report.ipynb" alt="S819118_report"> <img src="https://img.shields.io/static/v1?label=report&message=active&color=green" /></a><a href="https://github.com/RecoHut-Stanzas/S819118" alt="S819118"> <img src="https://img.shields.io/static/v1?label=code&message=github&color=blue" /></a> |
| S883757 | OLX Job Recommender | <a href="https://github.com/RecoHut-Stanzas/S883757/blob/main/reports/S883757_report.ipynb" alt="S883757_report"> <img src="https://img.shields.io/static/v1?label=report&message=active&color=green" /></a><a href="https://github.com/RecoHut-Stanzas/S883757" alt="S883757"> <img src="https://img.shields.io/static/v1?label=code&message=github&color=blue" /></a> |
| S873634 | Batch Learning in Stochastic Bandits | <a href="https://github.com/RecoHut-Stanzas/S873634/blob/main/reports/S873634_report.ipynb" alt="S873634_report"> <img src="https://img.shields.io/static/v1?label=report&message=active&color=green" /></a><a href="https://github.com/RecoHut-Stanzas/S873634" alt="S873634"> <img src="https://img.shields.io/static/v1?label=code&message=github&color=blue" /></a> |
| S832885 | Entire Item Space Exploration with Contextual Bandits | <a href="https://github.com/RecoHut-Stanzas/S832885/blob/main/reports/S832885_report.ipynb" alt="S832885_report"> <img src="https://img.shields.io/static/v1?label=report&message=active&color=green" /></a><a href="https://github.com/RecoHut-Stanzas/S832885" alt="S832885"> <img src="https://img.shields.io/static/v1?label=code&message=github&color=blue" /></a> |
| S241566 | Debiased Explainable Pairwise Ranking from Implicit Feedback | <a href="https://github.com/RecoHut-Stanzas/S241566/blob/main/reports/S241566_report.ipynb" alt="S241566_report"> <img src="https://img.shields.io/static/v1?label=report&message=active&color=green" /></a><a href="https://github.com/RecoHut-Stanzas/S241566" alt="S241566"> <img src="https://img.shields.io/static/v1?label=code&message=github&color=blue" /></a> |
| S035564 | Equal Experience in Recommender Systems | <a href="https://github.com/RecoHut-Stanzas/S035564/blob/main/reports/S035564_report.ipynb" alt="S035564_report"> <img src="https://img.shields.io/static/v1?label=report&message=active&color=green" /></a><a href="https://github.com/RecoHut-Stanzas/S035564" alt="S035564"> <img src="https://img.shields.io/static/v1?label=code&message=github&color=blue" /></a> |
| S346877 | Graph Meta Network for Multi-Behavior Recommendation | <a href="https://github.com/RecoHut-Stanzas/S346877/blob/main/reports/S346877_report.ipynb" alt="S346877_report"> <img src="https://img.shields.io/static/v1?label=report&message=active&color=green" /></a><a href="https://github.com/RecoHut-Stanzas/S346877" alt="S346877"> <img src="https://img.shields.io/static/v1?label=code&message=github&color=blue" /></a> |
| S063707 | Learning Robust Recommender from Noisy Implicit Feedback | <a href="https://github.com/RecoHut-Stanzas/S063707/blob/main/reports/S063707_report.ipynb" alt="S063707_report"> <img src="https://img.shields.io/static/v1?label=report&message=active&color=green" /></a><a href="https://github.com/RecoHut-Stanzas/S063707" alt="S063707"> <img src="https://img.shields.io/static/v1?label=code&message=github&color=blue" /></a> |
| S969915 | Self-Supervised Graph Co-Training for Session-based Recommendation | <a href="https://github.com/RecoHut-Stanzas/S969915/blob/main/reports/S969915_report.ipynb" alt="S969915_report"> <img src="https://img.shields.io/static/v1?label=report&message=active&color=green" /></a><a href="https://github.com/RecoHut-Stanzas/S969915" alt="S969915"> <img src="https://img.shields.io/static/v1?label=code&message=github&color=blue" /></a> |
| S810511 | Retail Session-based recommendations | <a href="https://github.com/RecoHut-Stanzas/S810511/blob/main/reports/S810511_report.ipynb" alt="S810511_report"> <img src="https://img.shields.io/static/v1?label=report&message=active&color=green" /></a><a href="https://github.com/RecoHut-Stanzas/S810511" alt="S810511"> <img src="https://img.shields.io/static/v1?label=code&message=github&color=blue" /></a> |
| S307784 | Real-time event capturing with Kafka and MongoDB | <a href="https://github.com/RecoHut-Stanzas/S307784/blob/main/reports/S307784_report.ipynb" alt="S307784_report"> <img src="https://img.shields.io/static/v1?label=report&message=active&color=green" /></a><a href="https://github.com/RecoHut-Stanzas/S307784" alt="S307784"> <img src="https://img.shields.io/static/v1?label=code&message=github&color=blue" /></a> |
| S632684 | Collaborative Filtering Models on MovieLens Dataset | <a href="https://github.com/RecoHut-Stanzas/S632684/blob/main/reports/S632684_report.ipynb" alt="S632684_report"> <img src="https://img.shields.io/static/v1?label=report&message=active&color=green" /></a><a href="https://github.com/RecoHut-Stanzas/S632684" alt="S632684"> <img src="https://img.shields.io/static/v1?label=code&message=github&color=blue" /></a> |
